@@ -78,7 +78,6 @@ OC.L10N.register(
     "Restore" : "Adfer",
     "Delete permanently" : "Dileu'n barhaol",
     "Could not update calendar order." : "Methu â diweddaru trefn y calendr.",
-    "Hidden" : "Cudd",
     "An error occurred, unable to publish calendar." : "Bu gwall, ni fu modd cyhoeddi'r calendr.",
     "An error occurred, unable to send email." : "Bu gwall, ni fu modd anfon e-bost.",
     "Embed code copied to clipboard." : "Mewnosod cod wedi'i gopïo i'r clipfwrdd.",
@@ -96,7 +95,6 @@ OC.L10N.register(
     "Delete share link" : "Dileu dolen rhannu",
     "Deleting share link …" : "Wrthi'n dileu dolen rhannu …",
     "An error occurred, unable to change the permission of the share." : "Bu gwall, ni fu modd newid caniatâd y gyfran.",
-    "can edit" : "yn gallu golygu",
     "Unshare with {displayName}" : "Dadrannu gyda {displayName}",
     "Share with users or groups" : "Rhannwch gyda defnyddwyr neu grwpiau",
     "No users or groups" : "Dim defnyddwyr na grwpiau",
@@ -137,13 +135,7 @@ OC.L10N.register(
     "CalDAV link copied to clipboard." : "Dolen CalDAV wedi'i chopïo i'r clipfwrdd.",
     "CalDAV link could not be copied to clipboard." : "Nid oedd modd copïo dolen CalDAV i'r clipfwrdd.",
     "General" : "Cyffredinol",
-    "Personal availability settings" : "Gosodiadau argaeledd personol",
-    "Copy primary CalDAV address" : "Copïo prig gyfeiriad CalDAV",
     "Copy iOS/macOS CalDAV address" : "Copïo cyfeiriad CalDAV iOS/macOS",
-    "Enable birthday calendar" : "Galluogi calendr pen-blwydd",
-    "Show tasks in calendar" : "Dangos tasgau yn y calendr",
-    "Show weekends" : "Dangos penwythnosau",
-    "Show week numbers" : "Dangos rhifau wythnosau",
     "Default reminder" : "Nodyn atgoffa rhagosodedig",
     "Keyboard shortcuts" : "Llwybrau byr bysellfwrdd",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} munud","{duration} funud","{duration} munud","{duration} munud"],
@@ -292,6 +284,7 @@ OC.L10N.register(
     "Maybe the share was deleted or has expired?" : "Efallai bod y gyfran wedi'i dileu neu wedi dod i ben?",
     "Yes" : "Ie",
     "No" : "Na",
+    "None" : "Dim",
     "from {formattedDate}" : "o {formattedDate}",
     "to {formattedDate}" : "i {formattedDate}",
     "on {formattedDate}" : "ar {formattedDate}",
@@ -398,7 +391,6 @@ OC.L10N.register(
     "When shared show full event" : "Pan wedi ei rannu, yn dangos y digwyddiad llawn",
     "When shared show only busy" : "Pan wedi ei rannu, yn dangos dim ond prysur",
     "When shared hide this event" : "Pan wedi ei rannu, yn cuddio'r digwyddiad hwn",
-    "The visibility of this event in shared calendars." : "Gwelededd y digwyddiad hwn mewn calendrau a rennir.",
     "Add a location" : "Ychwanegu lleoliad",
     "Status" : "Statws",
     "Confirmed" : "Cadarnhawyd",
@@ -416,10 +408,19 @@ OC.L10N.register(
     "Imported {filename}" : "Mewnforiwyd {filename}",
     "Appointment not found" : "Apwyntiad heb ei ganfod",
     "User not found" : "Defnyddiwr heb ei ganfod",
+    "Hidden" : "Cudd",
+    "can edit" : "yn gallu golygu",
     "Automatic ({detected})" : "Awtomatig ({detected})",
     "Shortcut overview" : "Trosolwg llwybr byr",
+    "Enable birthday calendar" : "Galluogi calendr pen-blwydd",
+    "Show tasks in calendar" : "Dangos tasgau yn y calendr",
     "Enable simplified editor" : "Galluogi golygydd symlach",
+    "Show weekends" : "Dangos penwythnosau",
+    "Show week numbers" : "Dangos rhifau wythnosau",
     "Time increments" : "Cynyddiadau amser",
-    "Show keyboard shortcuts" : "Dangos llwybrau byr bysellfwrdd"
+    "Copy primary CalDAV address" : "Copïo prig gyfeiriad CalDAV",
+    "Personal availability settings" : "Gosodiadau argaeledd personol",
+    "Show keyboard shortcuts" : "Dangos llwybrau byr bysellfwrdd",
+    "The visibility of this event in shared calendars." : "Gwelededd y digwyddiad hwn mewn calendrau a rennir."
 },
 "nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
