@@ -28,7 +28,6 @@ OC.L10N.register(
     "Delete permanently" : "Borrar permanentemente",
     "Deck" : "Deck",
     "Share link" : "Compartir liga",
-    "can edit" : "puede editar",
     "Share with users or groups" : "Compartir con otros usuarios o grupos",
     "Save" : "Guardar",
     "Filename" : "Nombre del archivo",
@@ -38,7 +37,6 @@ OC.L10N.register(
     "Actions" : "Acciones",
     "or" : "o",
     "General" : "General",
-    "Show week numbers" : "Mostrar número de semana",
     "Keyboard shortcuts" : "Atajos del teclado",
     "Update" : "Actualizar",
     "Location" : "Ubicación",
@@ -94,6 +92,8 @@ OC.L10N.register(
     "Status" : "Estatus",
     "Confirmed" : "Confirmado",
     "Categories" : "Categorías",
-    "Hidden" : "Oculto"
+    "Hidden" : "Oculto",
+    "can edit" : "puede editar",
+    "Show week numbers" : "Mostrar número de semana"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
