@@ -125,7 +125,6 @@ OC.L10N.register(
     "Deleting share link …" : "Menghapus tautan berbagi …",
     "An error occurred while unsharing the calendar." : "Terjadi kesalahan saat membatalkan pembagian kalender. ",
     "An error occurred, unable to change the permission of the share." : "Terjadi galat, tidak dapat mengubah hak akses berbagi.",
-    "can edit" : "dapat edit",
     "Unshare with {displayName}" : "Batal berbagi dengan {displayName}",
     "Share with users or groups" : "Berbagi dengan pengguna atau grup",
     "No users or groups" : "Tidak ada pengguna atau grup",
@@ -138,6 +137,7 @@ OC.L10N.register(
     "Invalid location selected" : "Lokasi yang tidak valid dipilih",
     "Attachments folder successfully saved." : "Folder lampiran berhasil disimpan.",
     "Error on saving attachments folder." : "Kesalahan saat menyimpan folder lampiran.",
+    "Attachments folder" : "Folder lampiran",
     "No valid files found, aborting import" : "Berkas valid tidak ditemukan, impor dibatalkan",
     "Import partially failed. Imported {accepted} out of {total}." : "Sebagian impor gagal. Dari {total} hanya {accepted} berhasil impor.",
     "Automatic" : "Otomatis",
@@ -158,12 +158,8 @@ OC.L10N.register(
     "CalDAV link copied to clipboard." : "Tautan CalDAV disalin ke papan klip",
     "CalDAV link could not be copied to clipboard." : "Tautan CalDAV tidak dapat disalin ke papan klip",
     "General" : "Umum",
-    "Copy primary CalDAV address" : "Salin alamat utama CalDAV",
     "Copy iOS/macOS CalDAV address" : "Salin alamat CalDAV iOS/macOS",
-    "Enable birthday calendar" : "Aktifkan kalender ulang tahun",
-    "Show tasks in calendar" : "Tampilkan tugas dalam kalender",
-    "Show weekends" : "Tampilkan akhir pekan",
-    "Show week numbers" : "Tampilkan nomor pekan",
+    "Appearance" : "Tampilan",
     "Editing" : "Pengeditan",
     "Keyboard shortcuts" : "Pintasan keyboard",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} menit"],
@@ -329,7 +325,6 @@ OC.L10N.register(
     "Please ask your administrator to enable the Tasks App." : "Silakan tanya administrator Anda untuk mengaktifkan aplikasi Tugas.",
     "_+%n more_::_+%n more_" : ["+%n lagi"],
     "Other" : "Lainnya",
-    "The visibility of this event in shared calendars." : "Visibilitas acara ini di kalender yang dibagikan.",
     "Add a location" : "Tambah lokasi",
     "Status" : "Status",
     "Confirmed" : "Terkonfirmasi",
@@ -345,9 +340,16 @@ OC.L10N.register(
     "An error occurred, unable to delete the calendar." : "Terjadi galat, tidak dapat menghapus kalender.",
     "This is an event reminder." : "Ini adalah pengingat acara.",
     "Hidden" : "Sembunyi",
+    "can edit" : "dapat edit",
     "Automatic ({detected})" : "Otomatis ({detected})",
     "Shortcut overview" : "Ikhtisar pintasan",
+    "Enable birthday calendar" : "Aktifkan kalender ulang tahun",
+    "Show tasks in calendar" : "Tampilkan tugas dalam kalender",
     "Enable simplified editor" : "Aktifkan editor serderhana",
-    "Show keyboard shortcuts" : "Tampilkan pintasan papan kunci"
+    "Show weekends" : "Tampilkan akhir pekan",
+    "Show week numbers" : "Tampilkan nomor pekan",
+    "Copy primary CalDAV address" : "Salin alamat utama CalDAV",
+    "Show keyboard shortcuts" : "Tampilkan pintasan papan kunci",
+    "The visibility of this event in shared calendars." : "Visibilitas acara ini di kalender yang dibagikan."
 },
 "nplurals=1; plural=0;");
