@@ -133,12 +133,10 @@ OC.L10N.register(
     "Deleting share link …" : "Deleting share link …",
     "An error occurred while unsharing the calendar." : "An error occurred while unsharing the calendar.",
     "An error occurred, unable to change the permission of the share." : "An error occurred, unable to change the permission of the share.",
-    "can edit" : "can edit",
     "Unshare with {displayName}" : "Unshare with {displayName}",
     "Share with users or groups" : "Share with users or groups",
     "No users or groups" : "No users or groups",
     "Failed to save calendar name and color" : "Failed to save calendar name and color",
-    "Calendar name …" : "Calendar name …",
     "Share calendar" : "Share calendar",
     "Unshare from me" : "Unshare from me",
     "Save" : "Save",
@@ -153,7 +151,7 @@ OC.L10N.register(
     "Invalid location selected" : "Invalid location selected",
     "Attachments folder successfully saved." : "Attachments folder successfully saved.",
     "Error on saving attachments folder." : "Error on saving attachments folder.",
-    "Default attachments location" : "Default attachments location",
+    "Attachments folder" : "Attachments folder",
     "{filename} could not be parsed" : "{filename} could not be parsed",
     "No valid files found, aborting import" : "No valid files found, aborting import",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Successfully imported %n event","Successfully imported %n events"],
@@ -184,13 +182,7 @@ OC.L10N.register(
     "CalDAV link copied to clipboard." : "CalDAV link copied to clipboard.",
     "CalDAV link could not be copied to clipboard." : "CalDAV link could not be copied to clipboard.",
     "General" : "General",
-    "Personal availability settings" : "Personal availability settings",
-    "Copy primary CalDAV address" : "Copy primary CalDAV address",
     "Copy iOS/macOS CalDAV address" : "Copy iOS/macOS CalDAV address",
-    "Enable birthday calendar" : "Enable birthday calendar",
-    "Show tasks in calendar" : "Show tasks in calendar",
-    "Show weekends" : "Show weekends",
-    "Show week numbers" : "Show week numbers",
     "Editing" : "Editing",
     "Default reminder" : "Default reminder",
     "Keyboard shortcuts" : "Keyboard shortcuts",
@@ -489,7 +481,6 @@ OC.L10N.register(
     "When shared show full event" : "When shared show full event",
     "When shared show only busy" : "When shared show only busy",
     "When shared hide this event" : "When shared hide this event",
-    "The visibility of this event in shared calendars." : "The visibility of this event in shared calendars.",
     "Add a location" : "Add a location",
     "Status" : "Status",
     "Confirmed" : "Confirmed",
@@ -513,11 +504,21 @@ OC.L10N.register(
     "Appointment not found" : "Appointment not found",
     "User not found" : "User not found",
     "Hidden" : "Hidden",
+    "can edit" : "can edit",
+    "Calendar name …" : "Calendar name …",
+    "Default attachments location" : "Default attachments location",
     "Automatic ({detected})" : "Automatic ({detected})",
     "Shortcut overview" : "Shortcut overview",
+    "Enable birthday calendar" : "Enable birthday calendar",
+    "Show tasks in calendar" : "Show tasks in calendar",
     "Enable simplified editor" : "Enable simplified editor",
     "Limit the number of events displayed in the monthly view" : "Limit the number of events displayed in the monthly view",
+    "Show weekends" : "Show weekends",
+    "Show week numbers" : "Show week numbers",
     "Time increments" : "Time increments",
-    "Show keyboard shortcuts" : "Show keyboard shortcuts"
+    "Copy primary CalDAV address" : "Copy primary CalDAV address",
+    "Personal availability settings" : "Personal availability settings",
+    "Show keyboard shortcuts" : "Show keyboard shortcuts",
+    "The visibility of this event in shared calendars." : "The visibility of this event in shared calendars."
 },
 "nplurals=2; plural=(n!=1);");
