@@ -25,13 +25,13 @@ OC.L10N.register(
     "Restore" : "Gjenopprett",
     "Delete permanently" : "Slett for godt",
     "Share link" : "Del lenkje",
-    "can edit" : "kan endra",
     "Save" : "Lagre",
     "Cancel" : "Avbryt",
     "Automatic ({timezone})" : "Automatisk ({tidssone})",
     "List view" : "Liste visning",
     "Actions" : "Handlingar",
     "General" : "Generelt",
+    "Appearance" : "Utsjånad",
     "Keyboard shortcuts" : "Tastatursnarvegar",
     "Update" : "Oppdater",
     "Location" : "Stad",
@@ -73,6 +73,7 @@ OC.L10N.register(
     "When shared show only busy" : "Når delt, vis berre oppteken",
     "When shared hide this event" : "Når delt, gøym denne hendinga",
     "Status" : "Status",
-    "Confirmed" : "Stadfesta"
+    "Confirmed" : "Stadfesta",
+    "can edit" : "kan endra"
 },
 "nplurals=2; plural=(n != 1);");
