@@ -147,7 +147,7 @@ OC.L10N.register(
     "{teamDisplayName} (Team)" : "{teamDisplayName} (Team)",
     "An error occurred while unsharing the calendar." : "Ett fel uppstod när delningen av kalendern skulle tas bort.",
     "An error occurred, unable to change the permission of the share." : "Ett fel inträffade. Det gick inte att ändra behörighet för delningen.",
-    "can edit" : "kan redigera",
+    "can edit and see confidential events" : "kan redigera och se konfidentiella händelser",
     "Unshare with {displayName}" : "Sluta dela med {displayName}",
     "Share with users or groups" : "Dela med användare eller grupper",
     "No users or groups" : "Inga användare eller grupper",
@@ -178,7 +178,7 @@ OC.L10N.register(
     "Invalid location selected" : "Ogiltig plats vald",
     "Attachments folder successfully saved." : "Mapp för bilagor har sparats ",
     "Error on saving attachments folder." : "Ett fel uppstod vid ändring av mapp för bilagor",
-    "Default attachments location" : "Standardplats för bilagor",
+    "Attachments folder" : "Mapp för bilagor",
     "{filename} could not be parsed" : "{filename} kunde inte läsas",
     "No valid files found, aborting import" : "Inga giltiga filer hittades, avbryter import",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Lyckades importera %n händelse","Lyckades importera %n händelser"],
@@ -212,18 +212,21 @@ OC.L10N.register(
     "CalDAV link copied to clipboard." : "CalDAV-länk kopierad till urklipp.",
     "CalDAV link could not be copied to clipboard." : "CalDAV-länk kunde inte kopieras till urklipp.",
     "General" : "Allmänt",
-    "Personal availability settings" : "Dina tillgänglighetsinställningar",
-    "Copy primary CalDAV address" : "Kopiera primär CalDAV-adress",
+    "Availability settings" : "Inställningar för tillgänglighet",
+    "CalDAV" : "CalDAV",
+    "Access Nextcloud calendars from other apps and devices" : "Åtkomst till Nextcloud-kalendrar från andra appar och enheter",
+    "CalDAV URL" : "CalDAV URL",
     "Copy iOS/macOS CalDAV address" : "Kopiera iOS/macOS CalDAV-adress",
-    "View options" : "Visningsalternativ",
-    "Enable birthday calendar" : "Aktivera födelsedagskalender",
-    "Show tasks in calendar" : "Visa uppgifter i kalendern",
-    "Show weekends" : "Visa helger",
-    "Show week numbers" : "Visa veckonummer",
-    "Limit number of events shown in month view" : "Begränsa antalet händelser som visas i månadsvyn",
-    "Time division in day and week view" : "Tidsindelning i dag- och vecko­vy",
+    "Appearance" : "Utseende",
+    "Birthday calendar" : "Födelsedagskalender",
+    "Tasks in calendar" : "Uppgifter i kalendern",
+    "Weekends" : "Helger",
+    "Week numbers" : "Veckonummer",
+    "Limit number of events shown in Month view" : "Begränsa antalet händelser som visas i månadsvyn",
+    "Density in Day and Week View" : "Täthet i dag- och vecko­vy",
     "Editing" : "Ändrar",
-    "Enable simple editor" : "Aktivera enkel redigerare",
+    "Simple event editor" : "Enkel händelseredigerare",
+    "\"More details\" opens the detailed editor" : "”Mer information” öppnar den detaljerade redigeraren",
     "Default calendar for incoming invitations" : "Standardkalender för inkommande inbjudningar",
     "Default reminder" : "Standardpåminnelse",
     "Keyboard shortcuts" : "Tangentbordsgenvägar",
@@ -347,6 +350,7 @@ OC.L10N.register(
     "optional participant" : "valfri deltagare",
     "{organizer} (organizer)" : "{organizer} (arrangör)",
     "{attendee} ({role})" : "{attendee} ({role})",
+    "Selected slot" : "Vald tidpunkt",
     "Availability of attendees, resources and rooms" : "Tillgänglighet för deltagare, resurser och lokaler",
     "Suggestion accepted" : "Förslaget accepterat",
     "Previous date" : "Föregående datum",
@@ -374,13 +378,11 @@ OC.L10N.register(
     "Decline" : "Avböj",
     "Tentative" : "Preliminärt",
     "No attendees yet" : "Inga deltagare än",
-    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} inbjudna, {confirmedCount} bekräftade",
     "Please add at least one attendee to use the \"Find a time\" feature." : "Lägg till minst en deltagare för att använda funktionen “Hitta en tid”.",
     "Successfully appended link to talk room to location." : "Länk till rum i Talk tillagd i plats.",
     "Successfully appended link to talk room to description." : "Länk till rum i Talk tillagd i beskrivningen.",
     "Error creating Talk room" : "Kunde inte skapa rum i Talk",
     "Attendees" : "Deltagare",
-    "_%n more guest_::_%n more guests_" : ["%n gäst till","%n gäster till"],
     "Remove group" : "Ta bort grupp",
     "Remove attendee" : "Ta bort deltagaren",
     "Request reply" : "Begär svar",
@@ -402,6 +404,7 @@ OC.L10N.register(
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Kan inte ändra inställning för heldag när händelsen är återkommande.",
     "From" : "Från",
     "To" : "Till",
+    "Your Time" : "Din tid",
     "Repeat" : "Upprepa",
     "Repeat event" : "Upprepa händelse",
     "_time_::_times_" : ["gång","gånger"],
@@ -641,7 +644,7 @@ OC.L10N.register(
     "When shared show full event" : "Om delad, visa hela händelsen",
     "When shared show only busy" : "Om delad, visa endast upptagen",
     "When shared hide this event" : "Om delad, dölj denna händelse",
-    "The visibility of this event in shared calendars." : "Synligheten för denna händelse i delade kalendrar.",
+    "The visibility of this event in read-only shared calendars." : "Synligheten för denna händelse i skrivskyddade delade kalendrar.",
     "Add a location" : "Lägg till en plats",
     "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Lägg till en beskrivning\n\n- Vad handlar mötet om\n- Punkter på dagordningen\n- Något som deltagare behöver förbereda",
     "Status" : "Status",
@@ -672,12 +675,27 @@ OC.L10N.register(
     "Appointment not found" : "Mötet hittades inte",
     "User not found" : "Användaren hittades inte",
     "Hidden" : "Gömd",
+    "can edit" : "kan redigera",
     "Calendar name …" : "Kalendernamn ...",
+    "Default attachments location" : "Standardplats för bilagor",
     "Automatic ({detected})" : "Automatisk ({detected})",
     "Shortcut overview" : "Översikt av genvägar",
+    "Enable birthday calendar" : "Aktivera födelsedagskalender",
+    "Show tasks in calendar" : "Visa uppgifter i kalendern",
     "Enable simplified editor" : "Aktivera förenklad redigerare",
     "Limit the number of events displayed in the monthly view" : "Begränsa antalet händelser som visas i månadsvyn",
+    "Show weekends" : "Visa helger",
+    "Show week numbers" : "Visa veckonummer",
     "Time increments" : "Tidsintervall",
-    "Show keyboard shortcuts" : "Visa tangentbordsgenvägar"
+    "Copy primary CalDAV address" : "Kopiera primär CalDAV-adress",
+    "Personal availability settings" : "Dina tillgänglighetsinställningar",
+    "Show keyboard shortcuts" : "Visa tangentbordsgenvägar",
+    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} inbjudna, {confirmedCount} bekräftade",
+    "_%n more guest_::_%n more guests_" : ["%n gäst till","%n gäster till"],
+    "The visibility of this event in shared calendars." : "Synligheten för denna händelse i delade kalendrar.",
+    "View options" : "Visningsalternativ",
+    "Limit number of events shown in month view" : "Begränsa antalet händelser som visas i månadsvyn",
+    "Time division in day and week view" : "Tidsindelning i dag- och vecko­vy",
+    "Enable simple editor" : "Aktivera enkel redigerare"
 },
 "nplurals=2; plural=(n != 1);");
