@@ -134,7 +134,6 @@ OC.L10N.register(
     "{teamDisplayName} (Team)" : "{teamDisplayName} (Team)",
     "An error occurred while unsharing the calendar." : "كالېندارنى ھەمبەھىرلەۋاتقاندا خاتالىق كۆرۈلدى.",
     "An error occurred, unable to change the permission of the share." : "ئورتاقلىشىشنىڭ رۇخسىتىنى ئۆزگەرتەلمەي خاتالىق كۆرۈلدى.",
-    "can edit" : "تەھرىرلىيەلەيدۇ",
     "Unshare with {displayName}" : "{displayName} بىلەن ئورتاقلاشماسلىق",
     "Share with users or groups" : "ئىشلەتكۈچىلەر ياكى گۇرۇپپىلار بىلەن ئورتاقلىشىڭ",
     "No users or groups" : "ئىشلەتكۈچى ياكى گۇرۇپپا يوق",
@@ -154,7 +153,7 @@ OC.L10N.register(
     "Invalid location selected" : "ئىناۋەتسىز ئورۇن تاللانغان",
     "Attachments folder successfully saved." : "قوشۇمچە ھۆججەت قىسقۇچ مۇۋەپپەقىيەتلىك ساقلاندى.",
     "Error on saving attachments folder." : "قوشۇمچە ھۆججەت قىسقۇچنى ساقلاشتا خاتالىق.",
-    "Default attachments location" : "كۆڭۈلدىكى قوشۇمچە ئورنى",
+    "Attachments folder" : "قوشۇمچە ھۆججەت قىسقۇچ",
     "{filename} could not be parsed" : "{filename} ئىسمى} تەھلىل قىلىشقا بولمايدۇ",
     "No valid files found, aborting import" : "ئۈنۈملۈك ھۆججەت تېپىلمىدى ، ئىمپورتنى ئەمەلدىن قالدۇردى",
     "Import partially failed. Imported {accepted} out of {total}." : "ئىمپورت قىسمەن مەغلۇپ بولدى. {accepted} دىن ئىمپورت قىلىنغان {total} قىلىندى}.",
@@ -186,13 +185,8 @@ OC.L10N.register(
     "CalDAV link copied to clipboard." : "CalDAV ئۇلىنىشى چاپلاش تاختىسىغا كۆچۈرۈلدى.",
     "CalDAV link could not be copied to clipboard." : "CalDAV ئۇلانمىسىنى چاپلاش تاختىسىغا كۆچۈرگىلى بولمايدۇ.",
     "General" : "General",
-    "Personal availability settings" : "شەخسىي ئىشلىتىش تەڭشىكى",
-    "Copy primary CalDAV address" : "دەسلەپكى CalDAV ئادرېسىنى كۆچۈرۈڭ",
     "Copy iOS/macOS CalDAV address" : "IOS / macOS CalDAV ئادرېسىنى كۆچۈرۈڭ",
-    "Enable birthday calendar" : "تۇغۇلغان كۈن كالىندارىنى قوزغىتىڭ",
-    "Show tasks in calendar" : "كالېنداردىكى ۋەزىپىلەرنى كۆرسەت",
-    "Show weekends" : "ھەپتە ئاخىرىنى كۆرسەت",
-    "Show week numbers" : "ھەپتە نومۇرىنى كۆرسەت",
+    "Appearance" : "كۆرۈنۈش",
     "Editing" : "تەھرىرلەش",
     "Default calendar for incoming invitations" : "كەلگەن تەكلىپلەرنىڭ سۈكۈتتىكى كالېندارى",
     "Default reminder" : "كۆڭۈلدىكى ئەسكەرتىش",
@@ -315,7 +309,6 @@ OC.L10N.register(
     "Decline" : "رەت قىلىش",
     "Tentative" : "Tentative",
     "No attendees yet" : "ھازىرغىچە قاتناشقۇچىلار يوق",
-    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} قىلىنغان سان} تەكلىپ قىلىنغان ، {confirmedCount} سان} جەزملەشتۈرۈلگەن",
     "Successfully appended link to talk room to location." : "مۇۋەپپەقىيەتلىك ھالدا پاراڭلىشىش ئۆيىگە ئۇلىنىش قوشۇلدى.",
     "Successfully appended link to talk room to description." : "مۇۋەپپەقىيەتلىك ھالدا سۆزلىشىش ئۆيىگە ئۇلىنىش قوشۇلدى.",
     "Error creating Talk room" : "سۆھبەت ئۆيى قۇرۇشتا خاتالىق",
@@ -498,7 +491,6 @@ OC.L10N.register(
     "When shared show full event" : "ھەمبەھىرلەنگەندە تولۇق پائالىيەتنى كۆرسىتىدۇ",
     "When shared show only busy" : "ئورتاقلاشقاندا پەقەت ئالدىراش",
     "When shared hide this event" : "ئورتاقلاشقاندا بۇ پائالىيەتنى يوشۇرۇڭ",
-    "The visibility of this event in shared calendars." : "ئورتاق كالېنداردا بۇ پائالىيەتنىڭ كۆرۈنۈشچانلىقى.",
     "Add a location" : "ئورۇن قوشۇڭ",
     "Status" : "ھالەت",
     "Confirmed" : "جەزملەشتۈرۈلدى",
@@ -523,12 +515,22 @@ OC.L10N.register(
     "Appointment not found" : "تەيىنلەنمىدى",
     "User not found" : "ئىشلەتكۈچى تېپىلمىدى",
     "Hidden" : "يۇشۇرۇن",
+    "can edit" : "تەھرىرلىيەلەيدۇ",
     "Calendar name …" : "كالېندار ئىسمى…",
+    "Default attachments location" : "كۆڭۈلدىكى قوشۇمچە ئورنى",
     "Automatic ({detected})" : "ئاپتوماتىك ({detected})",
     "Shortcut overview" : "تېزلەتمە ئومۇمىي كۆرۈنۈش",
+    "Enable birthday calendar" : "تۇغۇلغان كۈن كالىندارىنى قوزغىتىڭ",
+    "Show tasks in calendar" : "كالېنداردىكى ۋەزىپىلەرنى كۆرسەت",
     "Enable simplified editor" : "ئاددىيلاشتۇرۇلغان تەھرىرلىگۈچنى قوزغىتىڭ",
     "Limit the number of events displayed in the monthly view" : "ئايلىق كۆرۈنۈشتە كۆرسىتىلگەن پائالىيەت سانىنى چەكلەڭ",
+    "Show weekends" : "ھەپتە ئاخىرىنى كۆرسەت",
+    "Show week numbers" : "ھەپتە نومۇرىنى كۆرسەت",
     "Time increments" : "ۋاقىت كۆپەيدى",
-    "Show keyboard shortcuts" : "كۇنۇپكا تاختىسىنىڭ تېزلەتمىسىنى كۆرسەت"
+    "Copy primary CalDAV address" : "دەسلەپكى CalDAV ئادرېسىنى كۆچۈرۈڭ",
+    "Personal availability settings" : "شەخسىي ئىشلىتىش تەڭشىكى",
+    "Show keyboard shortcuts" : "كۇنۇپكا تاختىسىنىڭ تېزلەتمىسىنى كۆرسەت",
+    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} قىلىنغان سان} تەكلىپ قىلىنغان ، {confirmedCount} سان} جەزملەشتۈرۈلگەن",
+    "The visibility of this event in shared calendars." : "ئورتاق كالېنداردا بۇ پائالىيەتنىڭ كۆرۈنۈشچانلىقى."
 },
 "nplurals=2; plural=(n != 1);");
